@@ -7,8 +7,8 @@ stopifnot(all.equal(
 
 stopifnot(all.equal(
   stat.extend::CONF.var(.05, mtcars$mpg, N=1000),
-  structure(list(list(l = 21.4570190835676, r = 59.4753423696206, 
-                      lc = TRUE, rc = TRUE)), class = c("ci", "interval"), domain = "R", method = "Computed using nlm optimisation with 9 iterations (code = 1)", data = "Interval uses 32 data points from data mtcars$mpg with sample variance = 36.3241 and assumed kurtosis = 3.0000", confidence = 0.95, parameter = "variance for population of size 1000")
+  structure(list(list(l = 22.0730002460278, r = 57.9538604068809, 
+                      lc = TRUE, rc = TRUE)), class = c("ci", "interval"), domain = "R", method = "Computed using nlm optimisation with 7 iterations (code = 1)", data = "Interval uses 32 data points from data mtcars$mpg with sample variance = 36.3241 and sample kurtosis = 2.7995", confidence = 0.95, parameter = "variance for population of size 1000")
 ))
 
 stopifnot(all.equal(
